==> PyPtt-0.9.48.tar.gz: PyPtt-0.9.48/README.md <==
![](https://raw.githubusercontent.com/PttCodingMan/PyPtt/master/logo/facebook_cover_photo_2.png)
# PyPtt
[![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt)
![PyPI - Downloads](https://img.shields.io/pypi/dm/PyPtt)
[![PyPtt CI](https://github.com/PttCodingMan/PyPtt/workflows/PyPtt%20CI/badge.svg?branch=master)](https://github.com/PttCodingMan/PyPtt/actions)
[![codecov](https://codecov.io/gh/PttCodingMan/PyPtt/branch/master/graph/badge.svg)](https://codecov.io/gh/PttCodingMan/PyPtt)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/940fe61df0a0443ba883307e11e7b22d)](https://www.codacy.com/manual/PttCodingMan/PyPtt?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PttCodingMan/PyPtt&amp;utm_campaign=Badge_Grade)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/PyPtt)
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
[![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)

#### PyPtt (PTT Library) 是一套 Pure Python PTT API。具備大部分常用功能，無論推文、發文、爬蟲、寄信、發 P 幣、丟水球或者追蹤帳號，你都可以在這裡找到完整的使用範例
#### API 的詳細範例與參數說明 [PyPtt 文件](https://github.com/PttCodingMan/PyPtt/tree/master/doc)
#### Pypi: https://pypi.org/project/PyPtt/
<img src="https://i.imgur.com/wfaf8Bk.gif" width="480">

## 為什麼選擇 PyPtt
#### 完整的支援: PyPtt 是目前支援最完整的 PTT API，除了 PTT 也相容於 PTT2，也支援 [PTT docker](https://github.com/bbsdocker/imagebbs)，詳細範例請參考 [PyPtt 文件](https://github.com/PttCodingMan/PyPtt/tree/master/doc)
#### 即時的爬蟲: 登入式爬蟲，除了可以取得即時的推文，也可以下條件搜尋，不需要整個版都爬下來還需要清洗資料最後才能分析
#### 快速的客服: 如果有任何問題你可以在 [![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt) 找到我
#### 完整的測試: 你可以在 [![PyPtt CI](https://github.com/PttCodingMan/PyPtt/workflows/PyPtt%20CI/badge.svg?branch=master)](https://github.com/PttCodingMan/PyPtt/actions) 找到完整測試結果
#### 程式碼品質: 你可以在 [![Codacy Badge](https://api.codacy.com/project/badge/Grade/940fe61df0a0443ba883307e11e7b22d)](https://www.codacy.com/manual/PttCodingMan/PyPtt?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PttCodingMan/PyPtt&amp;utm_campaign=Badge_Grade) 找到程式碼品質報告與評等

## 版本
#### [![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt)

## 取得
#### 安裝
#### Windows 使用 pip, Linux and Mac 使用 pip3
```bash
pip install PyPtt
```

## 回報問題
#### 1. 請先閱讀 [PyPtt 文件](https://github.com/PttCodingMan/PyPtt/tree/master/doc) 確認使用方法無誤並確認你所使用的版本為 [![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt) 如果是舊版本請更新後複測
#### 2. 如果問題還是存在，請參考文件中的 [初始設定](https://github.com/PttCodingMan/PyPtt/tree/master/doc#%E5%88%9D%E5%A7%8B%E8%A8%AD%E5%AE%9A) 將 log_level 調整成 PTT.log.level.TRACE 後截圖並附上使用 PyPtt 的相關程式碼
#### 3. 請使用友善的態度開個 [issue](https://github.com/PttCodingMan/PyPtt/issues/new) 追蹤問題，或者直接在 [![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt) 上面描述你的問題，如何問問題可以參考[提問的藝術](https://github.com/ryanhanwu/How-To-Ask-Questions-The-Smart-Way)

## 需求
#### Python ≥ 3.6

## 相依函式庫
#### progressbar2
#### websockets
#### uao
#### [SingleLog](https://github.com/PttCodingMan/SingleLog)

## 立場聲明
#### 本專案意旨在提供 PTT 自動化機器人函式庫，並無意違反任何 PTT 站方規範。
#### 如有牴觸，請馬上告知。

## 贊助
#### 如果這個專案對你有幫助，贊助我一杯咖啡吧!!
####
#### [![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)
####
#### BTC
##### 1MiCSgTczPKzXbfsAH61gxXTLKoH4SsdMU
#### ETH
##### 0x60a23bf221cc6c7293134e7d11200c5c0e099fa4
#### ADA (recommend)
##### addr1qyzn7h06yp3ru6yncjq9mkrx4tn6fq566h3suph784wfd9q7vvtm9xvw3jqjrw9fsap8j6gkv3eywcdnvpd6c5fjxngspgqkry

## 贊助清單

#### leftc

==> PyPtt-1.0.3.tar.gz: PyPtt-1.0.3/README.md <==
![](https://raw.githubusercontent.com/PttCodingMan/PyPtt/master/logo/facebook_cover_photo_2.png)
# PyPtt
[![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt)
![PyPI - Downloads](https://img.shields.io/pypi/dm/PyPtt)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/940fe61df0a0443ba883307e11e7b22d)](https://www.codacy.com/manual/PttCodingMan/PyPtt?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PttCodingMan/PyPtt&amp;utm_campaign=Badge_Grade)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/PyPtt)
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
[![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)

#### PyPtt (PTT Library) 是一套 Pure Python PTT API。具備大部分常用功能，無論推文、發文、爬蟲、寄信、發 P 幣、丟水球或者追蹤帳號
你都可以在這裡找到完整的使用範例
#### API 的詳細範例與參數說明 PyPtt 文件 [0.9 版本](https://github.com/PttCodingMan/PyPtt/tree/master/doc), [1.0 版本](https://pyptt.cc/)
#### Pypi: https://pypi.org/project/PyPtt/
<img src="https://raw.githubusercontent.com/PyPtt/PyPtt/master/docs/_static/login_1.0.gif" width="560">


## 為什麼選擇 PyPtt
#### 完整的支援: PyPtt 是目前支援最完整的 PTT API，除了 PTT 也相容於 PTT2
#### 即時的爬蟲: 登入式爬蟲，除了可以取得即時的推文，也可以下條件搜尋，不需要整個版都爬下來還需要清洗資料最後才能分析
#### 快速的客服: 如果有任何問題你可以在 [![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt) 找到我

## 版本
#### [![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt)

## 安裝
Pypi: [https://pypi.org/project/PyPtt/](https://pypi.org/project/PyPtt/)
```bash
pip install PyPtt
```

## 回報問題
#### 1. 請先閱讀 PyPtt 文件 [0.9 版本](https://github.com/PttCodingMan/PyPtt/tree/master/doc), [1.0 版本](https://pyptt.cc/)
#### 確認使用方法無誤並確認你所使用的版本為 [![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt) 如果是舊版本請更新後重新測試
#### 2. 如果問題還是存在，請參考文件中的 [初始設定](https://github.com/PttCodingMan/PyPtt/tree/master/doc#%E5%88%9D%E5%A7%8B%E8%A8%AD%E5%AE%9A) 將 log_level 調整成 PTT.Logger.TRACE 後截圖並附上使用 PyPtt 的相關程式碼 [重要]
#### 3. 請用友善的態度開個 [issue](https://github.com/PttCodingMan/PyPtt/issues/new) 追蹤問題

## 需求
#### Python ≥ 3.8

## 立場聲明
#### 本專案意旨在提供 PTT 自動化機器人函式庫，並無意違反任何 PTT 站方規範。
#### 如有牴觸，請馬上告知。

## 贊助
#### 如果這個專案對你有幫助，贊助我一杯咖啡吧!!
####
#### [![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)

## 贊助清單

#### leftc
